@@ -323,7 +323,7 @@ class Attribute(Writer):
     name: str
     type: Optional[ClassWriter] = None
     default_value: Optional[str] = None
-    doc: Docstring = Docstring()
+    doc: Docstring = dataclasses_field(default_factory=lambda: Docstring())
 
     def write(self, mode: WritingMode = WritingMode.GENERATION, with_indentation: int = 0) -> str:
 
@@ -378,7 +378,7 @@ class Method(Writer):
     name: str
     parameters: List[Attribute]
     return_type: ClassWriter
-    doc: Docstring = Docstring()
+    doc: Docstring = dataclasses_field(default_factory=lambda: Docstring())
     errors: List[ClassWriter] = dataclasses_field(default_factory=list)
     body: Optional[str] = None
     additional_dependencies: List[ClassWriter] = dataclasses_field(default_factory=list)
